@@ -38,7 +38,7 @@ from calculate.lib.utils.files import (
     find, FindFileType, removeFileWithEmptyDirectory, check_rw,
     tar_xz_directory, sha256sum, quite_unlink,
     copyWithPath, countFiles, listDirectory, getRunCommands, readFile,
-    DirectoryRCS, RCSError, readLinesFile)
+    readFileEx, DirectoryRCS, RCSError, readLinesFile)
 from calculate.lib.utils.mount import isMount
 from calculate.lib.utils.git import Git
 from calculate.builder.variables.action import Actions
